@@ -1,11 +1,13 @@
 from flockai.PyCatascopia.probelib.ProcessProbe import ProcessProbe
 from flockai.models.drones.autopilot_controlled_drone import AutopilotControlledDrone
 from flockai.models.drones.keyboard_controller_drone import KeyboardControlledDrone
+from flockai.models.probes.flockai_probe import FlockAIProbe
 from flockai.models.sensors.humidity import HumiditySensor
 from flockai.models.sensors.temperature import TemperatureSensor
 from flockai.utils.string_generator import StringGenerator
 from flockai.models.devices.device_enums import EnableableDevice, NonEnableableDevice, MotorDevice
 from flockai.utils.intensive_thread import IntensiveThread
+import numpy as np
 
 
 class KeyboardMavic2DJI(KeyboardControlledDrone):
@@ -13,20 +15,20 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
     A Keyboard Controlled Mavic2DJI
     """
 
-    def __init__(self, devices, probes=None):
+    def __init__(self, devices, probe: FlockAIProbe=None, model=None):
         self.P_COMM = 8.4
         self.DJI_A3_FC = 8
         self.RASPBERRY_PI_4B_IDLE = 4
         self.RASPBERRY_PI_4B_ACTIVE = 8
         super().__init__(devices)
-        self.probes = probes
+        self.probe = probe
         self._activate_probes()
+        self.model = model
 
     def _activate_probes(self):
-        if self.probes:
-            for key, probe in self.probes.items():
-                probe.activate()
-                print(f'{key} probe activated')
+        if self.probe is not None:
+            self.probe.activate()
+            print(f'{self.probe.get_name()} probe activated')
 
     def send_msg(self, msg, emitter_devices: list):
         """
@@ -37,16 +39,16 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
         """
 
         total_time = 0
-        cpu_probe: ProcessProbe = self.probes['cpu']
+        probe_alive_time = self.probe.get_metric('ProbeAliveTimeMetric')
 
         for emitter in emitter_devices:
             if emitter not in self.devices:
                 print(f"The specified emitter device is not found: {emitter}")
                 return 0
             f_emitter = self.devices[emitter]['device']
-            t1 = cpu_probe.probe_alive_time.get_val()
+            t1 = probe_alive_time.get_val()
             f_emitter.send(msg.encode('utf-8'))
-            t2 = cpu_probe.probe_alive_time.get_val()
+            t2 = probe_alive_time.get_val()
             total_time += t2 - t1
 
         return total_time
@@ -57,9 +59,9 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
         :param receiver_devices: The receiver device name as a string
         :return: None
         """
-        cpu_probe: ProcessProbe = self.probes['cpu']
         total_time = 0
         messages = []
+        probe_alive_time = self.probe.get_metric('ProbeAliveTimeMetric')
 
         for receiver in receiver_devices:
             if receiver not in self.devices:
@@ -68,11 +70,11 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
 
             f_receiver = self.devices[receiver]['device']
             while f_receiver.getQueueLength() > 0:
-                t1 = cpu_probe.probe_alive_time.get_val()
+                t1 = probe_alive_time.get_val()
                 message_received = f_receiver.getData().decode('utf-8')
                 messages.append(message_received)
                 f_receiver.nextPacket()
-                t2 = cpu_probe.probe_alive_time.get_val()
+                t2 = probe_alive_time.get_val()
                 total_time += t2 - t1
 
         return messages, total_time
@@ -107,8 +109,10 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             if self.devices[device_name]['type'] == EnableableDevice.RECEIVER:
                 receiver_devices.append(device_name)
 
-        # self._activate_probes()
-        cpu_probe: ProcessProbe = self.probes['cpu']
+        probe_alive_time = self.probe.get_metric('ProbeAliveTimeMetric')
+        probe_cpu_time = self.probe.get_metric('ProcessCpuTimeMetric')
+        probe_io_time = self.probe.get_metric('ProcessIOTimeMetric')
+
         total_energy = 0
         net_transaction_time = 0
         temperature_sensor = TemperatureSensor('data/temperature_data.txt')
@@ -135,16 +139,21 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             received_messages, receive_time = self.receive_msgs(receiver_devices)
             # print("Receive time:", receive_time)
 
-            flight_time = cpu_probe.probe_alive_time.get_val()
-            cpu_time = cpu_probe.cpu_time.get_val()
-            io_time = 0 if cpu_probe.io_time.get_val() is None else cpu_probe.io_time.get_val()
+            flight_time = probe_alive_time.get_val()
+            cpu_time = probe_cpu_time.get_val()
+            t = probe_io_time.get_val()
+            io_time = 0 if t is None else t
             idle_time = flight_time - (cpu_time + io_time)
 
             total_energy += flight_time * self.DJI_A3_FC
             # print("Total energy consumed:", total_energy)
 
-            print('Humidity values', humidity_sensor.get_values())
+            humidity_max, humidity_min, humidity_avg = humidity_sensor.get_values()
+            temperature_max, temperature_min, temperature_avg = temperature_sensor.get_values()
 
+            input_vector = np.array([[temperature_max], [temperature_min], [temperature_avg],
+                                     [humidity_max], [humidity_min], [humidity_avg]]).reshape(1, -1)
+            # print(self.model.predict(input_vector))
 
 class AutopilotMavic2DJI(AutopilotControlledDrone):
     def __init__(self, devices):
